diff --git a/builder/builder.py b/builder/builder.py
index 9c671ab..92ad54b 100644
--- a/builder/builder.py
+++ b/builder/builder.py
@@ -60,7 +60,7 @@ class Builder:
                 message_handler=self._message_handler, python=python,
                 qmake=qmake)
 
-    def build(self, opt, nr_resources, clean, build_dir):
+    def build(self, opt, nr_resources, max_size, clean, build_dir):
         """ Build the project in a given directory.  Raise a UserException if
         there is an error.
         """
@@ -161,7 +161,7 @@ class Builder:
 
         # Generate the application resources.
         resource_names = self._generate_resources(parts, job_writer,
-                nr_resources)
+                nr_resources, max_size)
 
         # Write the .pro file.
         self._write_qmake(application_name, parts, job_writer, opt,
@@ -309,7 +309,7 @@ class Builder:
                 os.path.join(build_dir, 'frozen_' + name + '.h'),
                 bootstrap_path, 'pyqtdeploy_' + name, as_c=True)
 
-    def _generate_resources(self, parts, job_writer, nr_resources):
+    def _generate_resources(self, parts, job_writer, nr_resources, max_size):
         """ Generate the application resource files and return the names of
         the files relatve to the build directory.
         """
@@ -343,6 +343,26 @@ class Builder:
             per_resource = (nr_files + nr_resources - 1) // nr_resources
             start = 0
 
+            # pluck out files over `max-size`
+            large_resources_contents = []
+            if max_size is not None:
+                # root_dir = os.path.dirname(self._project.name)
+                root_dir = self._build_dir
+                for fname in list(resources_contents):
+                    fpath = os.path.join(root_dir, 'resources', fname)
+                    # if fpath[-4:] == '.pyo': # python module
+                    #     fpath = fpath[:-4] + '.py'
+                    try:
+                        b = os.stat(fpath).st_size
+                    except Exception as e:
+                        # print("Can't get file size for \"%s\"; skipping for consideration of --max-size" % fpath)
+                        continue
+                    if b >= (max_size * 1024):
+                        print("Separating resource %s into its own file because of --max-size." % fpath)
+                        resources_contents.remove(fname)
+                        large_resources_contents.append(fname)
+
+            # default distribution
             for r in range(nr_resources):
                 end = start + per_resource
                 if end > nr_files:
@@ -352,6 +372,11 @@ class Builder:
                         self._write_resource(resources_contents[start:end], r))
                 start += per_resource
 
+            # `max-size` distribution
+            for i, fpath in enumerate(large_resources_contents):
+                resource_names.append(
+                        self._write_resource([fpath], r + i))
+
         return resource_names
 
     def _get_abs_resource_path(self, rel_resource_path):
diff --git a/pyqtdeploybuild_main.py b/pyqtdeploybuild_main.py
index f68c167..3dba596 100644
--- a/pyqtdeploybuild_main.py
+++ b/pyqtdeploybuild_main.py
@@ -58,6 +58,10 @@ def main():
     parser.add_argument('--resources',
             help="the number of .qrc resource files to generate [default: 1]",
             metavar="NUMBER", type=int, default=1),
+    parser.add_argument('--max-size',
+            help="the maximum size in kilobytes before a resource is serialized into"
+                   "it's own source file. Ignored if --resources is 1",
+            type=int, default=None),
     parser.add_argument('--target', help="the target architecture"),
     parser.add_argument('--quiet', help="disable progress messages",
             action='store_true')
@@ -79,7 +83,7 @@ def main():
         builder = Builder(args.project, args.target, message_handler,
                 args.python, args.qmake)
 
-        builder.build(args.opt, args.resources, args.clean, args.build_dir)
+        builder.build(args.opt, args.resources, args.max_size, args.clean, args.build_dir)
     except UserException as e:
         message_handler.exception(e)
         return 1
